@@ -5,12 +5,12 @@ provided by the TU Munich in context of the research project iHEM
 
 """
 from copy import copy
+from typing import Any, Dict
 
-from pysimmods.buffer.batterysim import LOG
-from pysimmods.buffer.batterysim.config import BatteryConfig
-from pysimmods.buffer.batterysim.inputs import BatteryInputs
-from pysimmods.buffer.batterysim.state import BatteryState
-from pysimmods.model.buffer import Buffer
+from ...model.buffer import Buffer
+from .config import BatteryConfig
+from .inputs import BatteryInputs
+from .state import BatteryState
 
 
 class Battery(Buffer):
@@ -66,16 +66,15 @@ class Battery(Buffer):
 
     """
 
-    def __init__(self, params, inits):
-        self.config = BatteryConfig(params)
-        self.state = BatteryState(inits)
-        self.inputs = BatteryInputs()
+    def __init__(self, params: Dict[str, Any], inits: Dict[str, Any]):
+        self.config: BatteryConfig = BatteryConfig(params)
+        self.state: BatteryState = BatteryState(inits)
+        self.inputs: BatteryInputs = BatteryInputs()
 
     def step(self):
         """Perform a simulation step."""
 
         nstate = copy(self.state)
-
         self._check_inputs(nstate)
 
         self._calculate_efficiency(nstate)
@@ -90,24 +89,19 @@ class Battery(Buffer):
         self.state = nstate
         self.inputs.reset()
 
-    def _check_inputs(self, nstate):
+    def _check_inputs(self, nstate: BatteryState):
         """Check constraints for active power."""
         if self.inputs.p_set_kw is None:
             if self.inputs.now_dt is not None:
-                default_val = self.config.default_schedule[
+                nstate.p_kw = self.config.default_p_schedule[
                     self.inputs.now_dt.hour
                 ]
-                if self.config.use_decimal_percent:
-                    default_val *= 0.01
-
-                self.set_percent(default_val)
-                nstate.p_kw = self.inputs.p_set_kw
             else:
                 nstate.p_kw = 0
         else:
             nstate.p_kw = self.inputs.p_set_kw
 
-    def _calculate_efficiency(self, nstate):
+    def _calculate_efficiency(self, nstate: BatteryState):
         """Calculate efficiency using a second degree polynomial."""
 
         nstate._energy_kwh = self.config.cap_kwh * self.state.soc_percent / 100
@@ -119,9 +113,7 @@ class Battery(Buffer):
             + self.config.eta_pc[2]
         )
 
-    def _discharge(self, nstate):
-        LOG.debug("Battery is discharging.")
-
+    def _discharge(self, nstate: BatteryState):
         delta_energy_kwh = (
             nstate.p_kw
             / (nstate.eta_percent / 100)
@@ -146,7 +138,7 @@ class Battery(Buffer):
             )
             nstate.p_kw *= nstate.eta_percent / -100
 
-    def _charge(self, nstate):
+    def _charge(self, nstate: BatteryState):
         delta_energy_kwh = (
             nstate.p_kw
             * (nstate.eta_percent / 100)
