@@ -9,7 +9,7 @@ Example:
 import sys
 
 
-def chp_presets(p_kw, start_date="2017-01-01 00:00:00+0100", **kwargs):
+def chp_preset(p_kw, start_date="2017-01-01 00:00:00+0100", **kwargs):
     """Return the parameter configuration for a chp model
     from the pysimmods package.
 
