@@ -19,3 +19,6 @@ class CHPLPGSystemState(ModelState):
 
         self.lubricant_l = None
         """Among of lubricant remaining in [l]."""
+
+        self.e_th_demand_kwh = None
+        """Current heat demand of the household in [kW]"""
