@@ -222,7 +222,8 @@ class PysimmodsSimulator(mosaik_api.Simulator):
         for val in src_ids.values():
             if val is None:
                 continue
-            if isinstance(val, np.ndarray):
+            if isinstance(val, (list, np.ndarray)):
+                # This should only happen if palaestrAI is used
                 val = val[0]
             attr_sum += val
         attr_sum /= len(src_ids)
