@@ -85,20 +85,29 @@ class HeatStorage:
 
         return t_chilled
 
-    def get_absorbable_energy(self):
+    def get_absorbable_energy(self) -> float:
         """Return the amount of energy the storage can absorb."""
         e_th_in_max_kwh = (
-            -1 * C_WATER * self.cap_l * (self.t_max_c - self.t_c) / 3_600
+            C_WATER * self.cap_l * (self.t_max_c - self.t_c) / 3_600
         )
 
         return e_th_in_max_kwh
 
+    def get_available_energy(self) -> float:
+        """Return the amount of energy the storage has absorbed."""
+
+        e_th_in_min_kwh = (
+            C_WATER * self.cap_l * max(0, self.t_c - self.t_min_c) / 3_600
+        )
+
+        return e_th_in_min_kwh
+
     def absorb_energy(self, e_th_prod, e_th_demand):
 
         # 1 kWh = 3600 kJ
         e_th_delta_kj = (e_th_prod + e_th_demand) * 3_600
 
         t_chilled = self._calculate_chilled_t()
-        t_new = -e_th_delta_kj / (C_WATER * self.cap_l) + t_chilled
+        t_new = e_th_delta_kj / (C_WATER * self.cap_l) + t_chilled
 
-        self.t_c = max(t_new, self.t_min_c)
+        self.t_c = max(t_new, self.env_t_c)
